Flask-Uplink
============

Live realtime server rendered HTML inspired by Phoenix LiveView_.

.. _LiveView: https://github.com/phoenixframework/phoenix_live_view

Example:
--------
.. image:: https://user-images.githubusercontent.com/1269911/69392305-477f0080-0cde-11ea-9251-fedb41cfeacb.png



Under development (!!!)
-----------------------
**This is currently only a proof of concept**  

Please don't use it in production yet (unless you want to do something really simple, like, really simple)

Any help would be awesome!

Next up:
--------

* Fix the global state (looks awful right now)
* Use flask's constructs more
* Tests
* Everything else...
